# Generated by Django 3.1.7 on 2021-03-19 16:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('whoop', '0009_hr'),
    ]

    operations = [
        migrations.CreateModel(
            name='JournalEntry',
            fields=[
                ('tracker_id', models.IntegerField()),
                ('created_at', models.DateTimeField(max_length=200, null=True)),
                ('updated_at', models.DateTimeField(max_length=200, null=True)),
                ('title', models.CharField(max_length=200)),
                ('status', models.CharField(max_length=200, null=True)),
                ('category', models.CharField(max_length=200, null=True)),
                ('description', models.CharField(max_length=200, null=True)),
                ('question_text', models.CharField(max_length=200, null=True)),
                ('time_label', models.CharField(max_length=200, null=True)),
                ('time_context_label', models.CharField(max_length=200, null=True)),
                ('magnitude', models.JSONField(null=True)),
                ('default_tracker', models.BooleanField(null=True)),
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('journal_entry_id', models.IntegerField(null=True)),
                ('entry_created_at', models.DateTimeField(null=True)),
                ('entry_updated_at', models.DateTimeField(null=True)),
                ('answered_yes', models.BooleanField(null=True)),
                ('behavior_tracker_id', models.IntegerField(null=True)),
                ('time_input_value', models.DateTimeField(null=True)),
                ('time_input_label', models.CharField(max_length=200, null=True)),
                ('magnitude_input_label', models.CharField(max_length=200, null=True)),
                ('magnitude_input_value', models.IntegerField(null=True)),
                ('day', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.daily')),
            ],
        ),
    ]
