# Generated by Django 3.1.7 on 2021-03-18 19:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('whoop', '0007_auto_20210318_1400'),
    ]

    operations = [
        migrations.RenameField(
            model_name='workout',
            old_name='zone_6',
            new_name='zone_0',
        ),
    ]
