# Generated by Django 3.1.7 on 2021-03-18 18:33

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('whoop', '0004_auto_20210317_1430'),
    ]

    operations = [
        migrations.CreateModel(
            name='Daily',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('day', models.DateField()),
                ('during_bounds', models.CharField(max_length=10, null=True)),
                ('during_lower', models.DateTimeField(null=True)),
                ('during_upper', models.DateTimeField(null=True)),
                ('lastUpdatedAt', models.DateTimeField(null=True)),
                ('predictedEnd', models.DateTimeField(null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.whoopuser')),
            ],
        ),
        migrations.CreateModel(
            name='Sleep',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('needBreakdown_baseline', models.IntegerField(null=True)),
                ('needBreakdown_debt', models.IntegerField(null=True)),
                ('needBreakdown_naps', models.IntegerField(null=True)),
                ('needBreakdown_strain', models.IntegerField(null=True)),
                ('needBreakdown_total', models.IntegerField(null=True)),
                ('qualityDuration', models.IntegerField(null=True)),
                ('score', models.IntegerField(null=True)),
                ('day', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.daily')),
            ],
        ),
        migrations.CreateModel(
            name='Strain',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('averageHeartRate', models.FloatField(null=True)),
                ('kilojoules', models.FloatField(null=True)),
                ('maxHeartRate', models.FloatField(null=True)),
                ('rawScore', models.FloatField(null=True)),
                ('score', models.FloatField(null=True)),
                ('day', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.daily')),
            ],
        ),
        migrations.CreateModel(
            name='Workout',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('zone_1', models.IntegerField(null=True)),
                ('zone_2', models.IntegerField(null=True)),
                ('zone_3', models.IntegerField(null=True)),
                ('zone_4', models.IntegerField(null=True)),
                ('zone_5', models.IntegerField(null=True)),
                ('zone_6', models.IntegerField(null=True)),
                ('strain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.strain')),
            ],
        ),
        migrations.CreateModel(
            name='SleepDetail',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('cyclesCount', models.IntegerField(null=True)),
                ('disturbanceCount', models.IntegerField(null=True)),
                ('during_bounds', models.CharField(max_length=20, null=True)),
                ('during_lower', models.DateTimeField(null=True)),
                ('during_upper', models.DateTimeField(null=True)),
                ('inBedDuration', models.IntegerField(null=True)),
                ('isNap', models.BooleanField(default=False)),
                ('latencyDuration', models.IntegerField(null=True)),
                ('lightSleepDuration', models.IntegerField(null=True)),
                ('noDataDuration', models.IntegerField(null=True)),
                ('qualityDuration', models.IntegerField(null=True)),
                ('remSleepDuration', models.IntegerField(null=True)),
                ('respiratoryRate', models.FloatField(null=True)),
                ('score', models.IntegerField(null=True)),
                ('sleepConsistency', models.IntegerField(null=True)),
                ('sleepEfficiency', models.FloatField(null=True)),
                ('slowWaveSleepDuration', models.IntegerField(null=True)),
                ('timezoneOffset', models.CharField(max_length=20, null=True)),
                ('wakeDuration', models.IntegerField(null=True)),
                ('sleep', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.sleep')),
            ],
        ),
        migrations.CreateModel(
            name='Recovery',
            fields=[
                ('heartRateVariabilityRmssd', models.FloatField(null=True)),
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('restingHeartRate', models.FloatField(null=True)),
                ('score', models.FloatField(null=True)),
                ('timestamp', models.DateTimeField(null=True)),
                ('day', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='whoop.daily')),
            ],
        ),
    ]
